@@ -1,4 +1,4 @@
-import Queue
+import queue
 import threading
 import time
 import copy
@@ -31,7 +31,7 @@ log = getLogger()
 
 config = getConfig("PollThread")
 THREAD_POOL_SIZE = config['update_thread_pool_size']
-Qin = Queue.Queue()
+Qin = queue.Queue()
 ThreadPool = []
 
 heartbeat_times = None
@@ -77,7 +77,7 @@ def checkHeartBeat(global_count):
         dead_time = config['HeartBeatTimeOut']
         max_warnings = 5
 
-        if (latest_timeNow - last_time) > dead_time and this_thread.isAlive()\
+        if (latest_timeNow - last_time) > dead_time and this_thread.is_alive()\
                 and this_thread._currently_running_command is True\
                 and global_count < max_warnings:
 
@@ -121,7 +121,7 @@ class MonitoringWorkerThread(GangaThread):
                 try:
                     action = Qin.get(block=True, timeout=0.5)
                     break
-                except Queue.Empty:
+                except queue.Empty:
                     continue
 
             if self.should_stop():
@@ -203,7 +203,7 @@ def stop_and_free_thread_pool(fail_cb=None, max_retries=5):
 
     def join_worker_threads(threads, timeout=3):
         for t in threads:
-            if t.isAlive():
+            if t.is_alive():
                 t.join(timeout)
             t.stop()
 
@@ -216,7 +216,7 @@ def stop_and_free_thread_pool(fail_cb=None, max_retries=5):
     while True:
         if not fail_cb or max_retries <= 0:
             break
-        stalled = [t for t in ThreadPool if t.isAlive()]
+        stalled = [t for t in ThreadPool if t.is_alive()]
         if not stalled:
             break
         if fail_cb():  # continue?
@@ -245,7 +245,7 @@ def _purge_actions_queue():
             # fail to terminate
             if isType(action, JobAction) and action.function == 'stop':
                 Qin.put(action)
-        except Queue.Empty:
+        except queue.Empty:
             break
 
 if config['autostart_monThreads'] is True:
@@ -329,7 +329,7 @@ class UpdateDict(object):
         # number of update requests.
         # i.e. It's like getting a friend in the queue to pay for your
         # purchases as well! ;p
-        log.debug("*: backend=%s, isLocked=%s, isOwner=%s, joblist=%s, queue=%s" % (backend, lock._RLock__count, lock._is_owned(), [x.id for x in jobList], Qin.qsize()))
+        log.debug("*: backend=%s, isOwner=%s, joblist=%s, queue=%s" % (backend, lock._is_owned(), [x.id for x in jobList], Qin.qsize()))
         if lock.acquire(False):
             try:
                 jSetSize = len(jSet)
@@ -349,8 +349,8 @@ class UpdateDict(object):
             finally:
                 lock.release()
 
-            log.debug("**: backend=%s, isLocked=%s, isOwner=%s, joblist=%s, queue=%s" %
-                    (backend, lock._RLock__count, lock._is_owned(), [stripProxy(x).getFQID('.') for x in jobList], Qin.qsize()))
+            log.debug("**: backend=%s, isOwner=%s, joblist=%s, queue=%s" %
+                    (backend, lock._is_owned(), [stripProxy(x).getFQID('.') for x in jobList], Qin.qsize()))
             return True
 
     def clearEntry(self, backend):
@@ -387,7 +387,7 @@ class UpdateDict(object):
 
     def isBackendLocked(self, backend):
         if backend in self.table:
-            return bool(self.table[backend].entryLock._RLock__count)
+            return self.table[backend].entryLock._is_owned()
         else:
             return False
 
@@ -557,10 +557,10 @@ class JobRegistry_Monitor(GangaThread):
         """
         Main monitoring loop
         """
-        import thread
+        import _thread
         from GangaCore.Core.MonitoringComponent import monitoring_thread_id
-        monitoring_thread_id = thread.get_ident()
-        del thread
+        monitoring_thread_id = _thread.get_ident()
+        del _thread
 
         log.debug("Starting run method")
 
@@ -664,6 +664,7 @@ class JobRegistry_Monitor(GangaThread):
                 log.debug("Running monitoring callback hook function %s(**%s)" %(cbHookFunc, cbHookEntry.argDict))
                 #self.callbackHookDict[cbHookFunc][0](**cbHookEntry.argDict)
                 try:
+
                     if 'self' in cbHookEntry.argDict:
                         _argDict = copy.copy(cbHookEntry.argDict)
                         __self = _argDict['self']
@@ -1055,7 +1056,7 @@ class JobRegistry_Monitor(GangaThread):
                 log.debug("Reg LockError%s" % str(err))
 
         summary = '{'
-        for backend, these_jobs in active_backends.iteritems():
+        for backend, these_jobs in active_backends.items():
             summary += '"' + str(backend) + '" : ['
             for this_job in these_jobs:
                 summary += str(stripProxy(this_job).id) + ', '#getFQID('.')) + ', '
@@ -1083,7 +1084,7 @@ class JobRegistry_Monitor(GangaThread):
             #FIXME We've lost IList and the above method for adding a job which is in a submitted state looks like one that didn't work
             # Come back and fix this once 6.1.3 is out. We can drop features for functionalist here as the lazy loading is fixed in this release
             # rcurrie
-            alljobList_fromset = list(filter(lambda x: x.status in ['submitting', 'submitted', 'running'], jobListSet))
+            alljobList_fromset = list([x for x in jobListSet if x.status in ['submitting', 'submitted', 'running']])
             masterJobList_fromset = list()
 
             # print masterJobList_fromset
@@ -1192,7 +1193,7 @@ class JobRegistry_Monitor(GangaThread):
             activeBackends = activeBackendsFunc(jobSlice=jobSlice)
 
         summary = '{'
-        for this_backend, these_jobs in activeBackends.iteritems():
+        for this_backend, these_jobs in activeBackends.items():
             summary += '"' + this_backend + '" : ['
             for this_job in these_jobs:
                 summary += str(stripProxy(this_job).getFQID('.')) + ', '
@@ -1349,7 +1350,7 @@ def getStackTrace():
         #log.info("Queue", str(Qin.queue))
         log.debug("Trace: %s" % str(status))
         return status
-    except Exception, err:
+    except Exception as err:
         print("Err: %s" % str(err))
     finally:
         pass
