@@ -10,7 +10,7 @@ from functools import partial
 import inspect
 import abc
 import threading
-import thread
+import _thread
 from contextlib import contextmanager
 import functools
 
@@ -25,6 +25,8 @@ from GangaCore.Core.exceptions import GangaValueError, GangaException
 
 from GangaCore.Utility.Plugin import allPlugins
 
+from GangaCore.Utility.Profiling import cpu_profiler, mem_profiler, call_counter
+
 def _getName(obj):
     """ Return the name of an object based on what we prioritise 
     Name is defined as the first in the list of:
@@ -62,7 +64,7 @@ def synchronised(f):
     return sync_decorated
 
 
-class Node(object):
+class Node(object, metaclass=abc.ABCMeta):
     """
     The Node class is the code of the Ganga heirachy. It allows objects to keep
     track of their parent, whether they're dirty and take part in the visitor
@@ -71,7 +73,6 @@ class Node(object):
     It also provides access to tree-aware read/write locks to provide
     thread-safe usage.
     """
-    __metaclass__ = abc.ABCMeta
     __slots__ = ('_parent', '_lock', '_dirty')
 
     def __init__(self, parent=None):
@@ -84,7 +85,7 @@ class Node(object):
         cls = self.__class__
         obj = cls()
         this_dict = copy(self.__dict__)
-        for elem, val in this_dict.iteritems():
+        for elem, val in this_dict.items():
             if elem not in do_not_copy:
                 this_dict[elem] = deepcopy(val, memo)
 
@@ -123,7 +124,7 @@ class Node(object):
         object's root object.
 
         This lock acquires exclusive access over an object tree to prevent it
-        changing. Reading schema attributes on the object is still allowed
+        from changing. Reading schema attributes on the object is still allowed
         but changing them is not. Only one thread can hold this lock at once.
         """
         root = self._getRoot()
@@ -282,7 +283,7 @@ class Descriptor(object):
 
     """
     This is the Descriptor class used to deal with object assignment ot attribtues of the GangaObject.
-    This class handles the lazy-loading of an object from disk when needed to resturn a value stored in the Registry
+    This class handles the lazy-loading of an object from disk when needed to return a value stored in the Registry
     This class also handles thread-locking of a class including both the getter and setter methods to ensure object consistency
     """
 
@@ -403,7 +404,7 @@ class Descriptor(object):
             return int(v)
         elif isinstance(v, dict):
             new_dict = {}
-            for key, item in v.iteritems():
+            for key, item in v.items():
                 new_dict[key] = Descriptor.cloneObject(item, obj, name)
             return new_dict
         else:
@@ -687,8 +688,10 @@ class ObjectMetaclass(abc.ABCMeta):
             this_schema.createDefaultConfig()
 
 
-class GangaObject(Node):
-    __metaclass__ = ObjectMetaclass # Change standard Python metaclass object
+@call_counter
+@cpu_profiler
+@mem_profiler
+class GangaObject(Node, metaclass=ObjectMetaclass):
     _schema = None  # obligatory, specified in the derived classes
     _category = None  # obligatory, specified in the derived classes
     _exportmethods = []  # optional, specified in the derived classes
@@ -733,7 +736,7 @@ class GangaObject(Node):
         setattr(returnable, '_should_init', should_init)
         GangaObject.__init__(returnable)
         try:
-            # Initialize the most derrived class to get all of the goodness needed higher up.
+            # Initialize the most derived class to get all of the goodness needed higher up.
             returnable.__class__.__init__(returnable)
         except:
             logger.debug("Broken init method for class: %s trying to proceed silently" % cls.__name__)
@@ -837,7 +840,7 @@ class GangaObject(Node):
 
         ## Fix some objects losing parent knowledge
         src_dict = srcobj.__dict__
-        for key, val in src_dict.iteritems():
+        for key, val in src_dict.items():
             this_attr = getattr(srcobj, key)
             if isinstance(this_attr, Node) and key not in do_not_copy:
                 #logger.debug("k: %s  Parent: %s" % (key, (srcobj)))
@@ -1038,7 +1041,7 @@ class GangaObject(Node):
                 if item.isA(SharedItem):
                     self.__incrementShareRef(self_copy, name)
 
-        for k, v in self.__dict__.iteritems():
+        for k, v in self.__dict__.items():
             if k not in do_not_copy:
                 try:
                     self_copy.__dict__[k] = deepcopy(v)
@@ -1064,7 +1067,7 @@ class GangaObject(Node):
         from GangaCore.Utility.Config.Config import getConfig, ConfigError
         try:
             _timeOut = getConfig('Configuration')['DiskIOTimeout']
-        except ConfigError, err:
+        except ConfigError as err:
             _timeOut = 5. # 5sec hardcoded default
         return _timeOut
 
@@ -1137,7 +1140,7 @@ class GangaObject(Node):
         """
         try:
             return self._registry.find(self)
-        except AttributeError, err:
+        except AttributeError as err:
             logger.debug("_getRegistryID Exception: %s" % err)
             return None
 
