@@ -1,4 +1,4 @@
-from __future__ import print_function
+
 
 ##########################################################################
 # Ganga Project. http://cern.ch/ganga
@@ -172,7 +172,7 @@ class Root(IPrepareApp):
     if __name__ == '__main__':
         from ROOT import gRandom
 
-        output = file('gaus.txt','w')
+        output = open('gaus.txt','w')
         try:
             for i in range(100):
                 print(gRandom.Gaus(), file=output)
@@ -500,7 +500,7 @@ def downloadWrapper(app):
                 arglist.append('\\\'' + arg + '\\\'')
             else:
                 arglist.append(arg)
-        rootarg = '\(\"' + string.join([str(s) for s in arglist], ',') + '\"\)'
+        rootarg = r'\(\"' + ','.join([str(s) for s in arglist]) + r'\"\)'
 
         # use root
         commandline = 'root.exe -b -q ' + scriptPath + rootarg + ''
@@ -561,7 +561,7 @@ def defaultPyRootScript():
 def randomString():
     """Simple method to generate a random string"""
     from random import randint
-    from string import ascii_uppercase, join
+    from string import ascii_uppercase
 
     def addToSample(sample, ascii_length):
         """Basically random.select but python2.2"""
@@ -579,6 +579,6 @@ def randomString():
     assert(len(sample) == 6)
 
     # seed is set to clock during import
-    return join([str(a) for a in sample], '')
+    return ''.join([str(a) for a in sample])
 
 
