@@ -1,4 +1,4 @@
-from __future__ import print_function
+
 
 import os
 import shutil
@@ -40,8 +40,8 @@ def gpi(request, wipe_gangadir):
     ``GangaCore.GPI`` inside the function as usual.
     """
     config_values = getattr(request._pyfuncitem._obj, '_config_values', {})
-    config_values = [(k[0], k[1], v) for k, v in config_values.items()]  # Convert from dict to a list of tuples
-
+    config_values = [(k[0], k[1], v) for k, v in list(config_values.items())]  # Convert from dict to a list of tuples
+#    testLHCb = request.config.getoption("--testLHCb")
     start_ganga(gangadir(request), extra_opts=config_values)
 
     import GangaCore.GPI
