@@ -99,7 +99,7 @@ logger = getLogger()
 global_random = random
 
 LFN_parallel_limit = 250.
-def wrapped_execute(command, expected_type):
+def wrapped_execute(command, expected_type, new_subprocess = False):
     """
     A wrapper around execute to protect us from commands which had errors
     Args:
@@ -107,7 +107,7 @@ def wrapped_execute(command, expected_type):
         expected_type (type): This is the type of the object which is returned from DIRAC
     """
     try:
-        result = execute(command)
+        result = execute(command, new_subprocess)
         assert isinstance(result, expected_type)
     except AssertionError:
         raise SplitterError("Output from DIRAC expected to be of type: '%s', we got the following: '%s'" % (expected_type, result))
@@ -164,7 +164,7 @@ def getLFNReplicas(allLFNs, index, allLFNData):
         this_max = int((index + 1) * LFN_parallel_limit)
 
     try:
-        output = wrapped_execute('getReplicasForJobs(%s)' % str(allLFNs[this_min:this_max]), dict)
+        output = wrapped_execute('getReplicasForJobs(%s)' % str(allLFNs[this_min:this_max]), dict, new_subprocess = True)
     except SplitterError:
         logger.error("Failed to Get Replica Info: [%s:%s] of %s" % (str(this_min), str(this_max), len(allLFNs)))
         raise
@@ -249,7 +249,7 @@ def calculateSiteSEMapping(file_replicas, uniqueSE, CE_to_SE_mapping, SE_to_CE_m
     # First find the SE for each site - there is a handy DIRAC function that gives us everything quickly
     CE_to_SE_mapping = wrapped_execute('getSESiteMapping()', dict)
 
-    for lfn, repz in file_replicas.iteritems():
+    for lfn, repz in file_replicas.items():
         sitez = set([])
         for replica in repz:
             sitez.add(replica)
@@ -257,7 +257,7 @@ def calculateSiteSEMapping(file_replicas, uniqueSE, CE_to_SE_mapping, SE_to_CE_m
         SE_dict[lfn] = sitez
 
     # Remove the banned sites (CE) from the mappings
-    for iSE in CE_to_SE_mapping.keys():
+    for iSE in list(CE_to_SE_mapping.keys()):
         for site in CE_to_SE_mapping[iSE]:
             if any(site == item for item in bannedSites):
                 CE_to_SE_mapping[iSE].remove(site)
@@ -265,7 +265,7 @@ def calculateSiteSEMapping(file_replicas, uniqueSE, CE_to_SE_mapping, SE_to_CE_m
                 del CE_to_SE_mapping[iSE]
 
     # Now calculate the 'inverse' dictionary of site for each SE
-    for SE, sites in CE_to_SE_mapping.iteritems():
+    for SE, sites in CE_to_SE_mapping.items():
         for site_i in sites:
             if site_i not in SE_to_CE_mapping:
                 SE_to_CE_mapping[site_i] = set([])
@@ -278,7 +278,7 @@ def calculateSiteSEMapping(file_replicas, uniqueSE, CE_to_SE_mapping, SE_to_CE_m
     # Now lets generate a dictionary of some chosen site vs LFN to use in
     # constructing subsets
     site_dict = {}
-    for lfn, sites in SE_dict.iteritems():
+    for lfn, sites in SE_dict.items():
         site_dict[lfn] = set([])
         for site in sites:
             if site in CE_to_SE_mapping.keys():
@@ -330,12 +330,17 @@ def lookUpLFNReplicas(inputs, ignoremissing):
     # Sort this information and store is in the relevant Ganga objects
     updateLFNData(bad_lfns, allLFNs, LFNdict, ignoremissing, allLFNData)
 
+    file_replicas = {}
+    for _lfn in LFNdict:
+        if not _lfn in bad_lfns:
+            file_replicas[_lfn] = LFNdict[_lfn].locations
+
     # Check if we have any bad lfns
     if bad_lfns and ignoremissing is False:
         logger.error("Errors found getting LFNs:\n%s" % str(bad_lfns))
         raise SplitterError("Error trying to split dataset with invalid LFN and ignoremissing = False")
 
-    return bad_lfns
+    return bad_lfns, file_replicas
 
 
 def updateLFNData(bad_lfns, allLFNs, LFNdict, ignoremissing, allLFNData):
@@ -382,7 +387,7 @@ def updateLFNData(bad_lfns, allLFNs, LFNdict, ignoremissing, allLFNData):
                 logger.error("Error updating remoteURLs for: %s" % str(this_lfn))
 
             # If we find NO replicas then also mark this as bad!
-            if this_dict[this_lfn].keys() == []:
+            if list(this_dict[this_lfn].keys()) == []:
                 bad_lfns.append(this_lfn)
 
         for this_lfn in bad_lfns:
@@ -433,16 +438,10 @@ def OfflineGangaDiracSplitter(_inputs, filesPerJob, maxFiles, ignoremissing, ban
     logger.info("Requesting LFN replica info")
 
     # Perform a lookup of where LFNs are all stored
-    bad_lfns = lookUpLFNReplicas(inputs, ignoremissing)
+    bad_lfns, file_replicas = lookUpLFNReplicas(inputs, ignoremissing)
 
     logger.info("Got all good replicas")
 
-    for this_input in inputs:
-        if this_input.lfn not in bad_lfns:
-            file_replicas[this_input.lfn] = this_input.locations
-
-    logger.info("found all replicas")
-
     # This contains information on the mapping between CE and SE(site) in DIRAC as multiple CE may access an SE(site)
     CE_to_SE_mapping = {}
     # This contains the mapping between the SE and the CE
@@ -527,11 +526,11 @@ def performSplitting(site_dict, filesPerJob, allChosenSets, wanted_common_site,
 
     iterations = 0
     # Loop over all LFNs
-    while len(site_dict.keys()) > 0:
+    while len(site_dict) > 0:
 
         # LFN left to be used
         # NB: Can't modify this list and iterate over it directly in python
-        LFN_instances = site_dict.keys()
+        LFN_instances = list(site_dict.keys())
         # Already used LFN
         chosen_lfns = set()
 
