@@ -92,7 +92,7 @@ def getScriptName(app):
         app (Job): This is the app object which contains everything useful for generating the code
     """
     job = app.getJobObject()
-    return "_".join((getConfig('Configuration')['user'], getName(app), 'Job', job.getFQID('.'), _pseudo_session_id, 'script'))+'.py'
+    return "_".join((getName(app), getConfig('Configuration')['user'], 'Job', job.getFQID('.'), _pseudo_session_id, 'script'))+'.py'
 
 
 def generateWNScript(commandline, app):
@@ -128,8 +128,16 @@ def collectPreparedFiles(app):
 
     for file_ in app.getJobObject().inputfiles:
         if isinstance(file_, LocalFile):
+            if file_.namePattern == 'data.py':
+                raise ApplicationConfigurationError("You should not name any inputfiles 'data.py' to avoid conflict with the generated inputdata. Please rename the file and submit again.")
             shutil.copy(os.path.join(file_.localDir, os.path.basename(file_.namePattern)), shared_dir)
             input_files.append(os.path.join(shared_dir, file_.namePattern))
+        elif isinstance(file_, str):
+            if 'data.py' in file_:
+                raise ApplicationConfigurationError("You should not name any inputfiles 'data.py' to avoid conflict with the generated inputdata. Please rename the file and submit again.")
+            new_file = LocalFile(file_)
+            shutil.copy(os.path.join(new_file.localDir, os.path.basename(new_file.namePattern)), shared_dir)
+            input_files.append(os.path.join(shared_dir, new_file.namePattern))
         elif not isinstance(file_, DiracFile):
             raise ApplicationConfigurationError(None, "File type: %s Not _yet_ supported in GaudiExec" % type(file_))
 
@@ -143,18 +151,26 @@ def prepareCommand(app):
         app (GaudiExec): This expects only the GaudiExec app
     """
 
-    all_opts_files = app.getOptsFiles()
+    all_opts_files = app.getOptsFiles(True)
     opts_names = []
     for opts_file in all_opts_files:
         if isinstance(opts_file, (LocalFile, DiracFile)):
             # Ideally this would NOT need the basename, however LocalFile is special in this regard.
             # TODO Fix this after fixing LocalFile
             opts_names.append(os.path.basename(opts_file.namePattern))
+        elif isinstance(opts_file, str):
+            opts_names.append(os.path.basename(opts_file))
         else:
             raise ApplicationConfigurationError("The filetype: %s is not yet supported for use as an opts file.\nPlease contact the Ganga devs is you wish this implemented." %
                                                 getName(opts_file))
 
-    sourceEnv = app.getWNEnvScript()
+    #Check if this was checked out with LbEnv or not
+    isLbEnv = False
+    with open(app.directory+'/Makefile', "r") as makefile:
+        if 'LbEnv' in makefile.read():
+            isLbEnv = True
+
+    sourceEnv = app.getWNEnvScript(isLbEnv)
 
     run_cmd = ' export ganga_jobid=%s && ./run ' % app.getJobObject().fqid
 
@@ -556,7 +572,7 @@ class GaudiExecDiracRTHandler(IRuntimeHandler):
 
         # We can support inputfiles and opts_file here. Locally should be submitted once, remotely can be referenced.
 
-        all_opts_files = app.getOptsFiles()
+        all_opts_files = app.getOptsFiles(True)
 
         for opts_file in all_opts_files:
             if isinstance(opts_file, DiracFile):
